@@ -12,12 +12,14 @@
                          /*          DELETE_SEQUENCE                          */
 // #define BELL_AUDIBLE           TRUE
 // #define BELL_VISIBLE           TRUE
+// #define BELL_URGENT            TRUE
 // #define BUTTON_ORDER_BY_RCFILE TRUE
 // #define CLOSE_DIALOG           TRUE  /* Dialog to confirm close event      */
 // #define CLOSE_SAFELY           TRUE  /* Do not kill running applications   */
 // #define COLOR_BACKGROUND       "white"
 // #define COLOR_FOREGROUND       "#000000"
-// #define COLOR_STYLE   /* Options: VTE_FIXED, LINUX, RXVT, TANGO, XTERM     */
+// #define COLOR_STYLE   /* Options: VTE_FIXED, LINUX, RXVT, TANGO, XTERM,    */
+                         /*          ZENBURN                                  */
 // #define COLOR_TEXT_BOLD        "red"
 // #define COLOR_TEXT_DIM         "#FFFF00"
 // #define COLOR_TEXT_HIGHLIGHTED "green"
@@ -25,6 +27,8 @@
 // #define COMMAND_DOCK_MODE      TRUE  /* -d option, run as a dock           */
 #define    COMMAND_EXEC_PROGRAM   TRUE  /* -e option, execute program         */
 // #define COMMAND_FULLSCREEN     TRUE  /* -f option, init in fullscreen mode */
+// #define COMMAND_FONT           TRUE  /* -fn option, to assign font & size  */
+// #define COMMAND_GEOMETRY       TRUE  /* -g +X+Y option, to assign geometry */
 // #define COMMAND_LOGIN_SHELL    TRUE  /* -ls option, to enable login shell  */
 // #define COMMAND_SET_TITLE      TRUE  /* -T or -title to set program title  */
 // #define COMMAND_SHOW_HELP      TRUE  /* -h option, show help               */
@@ -36,7 +40,6 @@
 // #define CURSOR_SHAPE  /* Options: BLOCK, IBEAM, UNDERLINE                  */
 // #define DEFAULT_COMMAND        g_getenv("SHELL")
 // #define DEFAULT_DIRECTORY      g_get_current_dir()
-// #define DEFAULT_EMULATION_TYPE "xterm"
 // #define DEFAULT_ENCODING       "UTF-8"
 // #define DEFAULT_TERMINAL_SIZE  80x24
 // #define FONT                   "Monospace 10"
@@ -55,7 +58,7 @@
 // #define SCROLL_LINES           1000  /* Negative value means unlimited     */
 // #define SCROLL_ON_KEYSTROKE    TRUE
 // #define SCROLL_ON_OUTPUT       TRUE
-#define    SCROLLBAR              RIGHT /* Options: LEFT, RIGHT               */
+#define    SCROLLBAR              RIGHT /* Options: LEFT, RIGHT, OFF_L, OFF_R */
 // #define SHOW_WINDOW_BORDER     TRUE
 // #define SHOW_WINDOW_DECORATED  TRUE
 #define    SHOW_WINDOW_ICON       TRUE
@@ -66,25 +69,30 @@
 #define    MENU                   TRUE
 // #define MENU_ENCODING_LIST     "BIG-5", "Default Encoding", "GBK", "EUC-JP"
 // #define MENU_MATCH_STRING_EXEC "firefox"
-// #define      MATCH_STRING_EXEC "firefox" /* click to open, no menu needed  */
-// #define      MATCH_STRING      "((f|F)(t|T)(p|P)|((h|H)(t|T)(t|T)(p|P)(s|S)*))://[-a-zA-Z0-9.?$%&/=_~#.,:;+]*"
+// #define      MATCH_STRING_L    "firefox" /* left click to open without menu*/
+// #define      MATCH_STRING_M    "firefox" /* middle click to open           */
+// #define      MATCH_STRING_HTTP TRUE      /* Detect http(s) and ftp(s)      */
+// #define      MATCH_STRING_MAIL TRUE      /* Detect mailto:                 */
+// #define      MATCH_STRING_FILE TRUE      /* Detect file:///                */
 // #define MENU_CUSTOM            "Copy", "Separator", "Paste", "Separator"
-           /* Options: "Copy", "Paste", "Select all", "Add tab", "Remove tab",
-            *          "Edit label", "New window", "Quit", "Zoom in",
-            *          "Zoom out", "Zoom default", "Reset terminal",
-            *          "Reset and clear", "Select font", "Separator",
-            *          "Encoding list", "Input method", "Submenu encoding list",
-            *          "Submenu input method", "Toggle background",
-            *          "Toggle scrollbar", "Toggle status bar",
-            *          "Toggle tabbar", "Toggle window decorated",
-            *          "Toggle anti-alias", "Toggle hotkeys locking",
-            *          "Toggle always on top", "Toggle fullscreen",
-            *          "Adjust saturation", "Background tint"                 */
+           /* Options: "Copy",         "Zoom in",       "Add tab",
+            *          "Paste",        "Zoom out",      "Remove tab",
+            *          "Select all",   "Zoom default",  "New window",
+            *          "Edit label",   "Select font",
+            *          "Input method",                  "Encoding list",
+            *          "Submenu input method",          "Submenu encoding list",
+            *          "Toggle tabbar",
+            *          "Toggle scrollbar",              "Background tint",
+            *          "Toggle status bar",             "Adjust saturation",
+            *          "Toggle anti-alias",
+            *          "Toggle background",             "Separator",
+            *          "Toggle fullscreen",             "Quit",
+            *          "Toggle always on top",
+            *          "Toggle hotkeys locking",        "Reset terminal",
+            *          "Toggle window decorated",       "Reset and clear"     */
 
 #define    TAB                    TRUE
 // #define TAB_BORDER             0
-// #define TAB_BORDER_HORIZONTAL  0
-// #define TAB_BORDER_VERTICAL    0
 // #define TAB_CLOSE_BUTTON       TRUE
 // #define TAB_EXPANDED_WIDTH     TRUE
 // #define TAB_LABEL              "Page %u" /* %u will be replaced by numbers */
@@ -106,7 +114,7 @@
  * CTRL GDK_a = "Ctrl + a"
  * CTRL GDK_A = "Ctrl + Shift + a"
  *
- * See /usr/include/gtk-2.0/gdk/gdkkeysyms.h for GDK_* definitions.
+ * See /usr/include/gtk-?.0/gdk/gdkkeysyms.h for GDK_* definitions.
  *
  * If you enable "CTRL_ALT", all hotkeys will become Ctrl + Alt + hotkey(s).  */
 
@@ -121,12 +129,17 @@
 // #define HOTKEY_FONT_SMALLER          CTRL GDK_KP_Subtract
 // #define HOTKEY_FONT_DEFAULT_SIZE     CTRL GDK_KP_Insert
 // #define HOTKEY_FONT_SELECT           CTRL GDK_F
+// #define HOTKEY_MIMIC_SCROLL_UP       CTRL GDK_K
+// #define HOTKEY_MIMIC_SCROLL_DOWN     CTRL GDK_J
 // #define HOTKEY_OPEN_NEW_WINDOW       CTRL GDK_N
 // #define HOTKEY_RESET_TERMINAL        CTRL GDK_R
 // #define HOTKEY_RESET_AND_CLEAR       CTRL GDK_A
 // #define HOTKEY_SATURATION_DIALOG     CTRL GDK_X
 // #define HOTKEY_SATURATION_MORE       CTRL GDK_KP_Multiply
 // #define HOTKEY_SATURATION_LESS       CTRL GDK_KP_Divide
+// #define HOTKEY_SEARCH_STRING         CTRL GDK_Q
+// #define HOTKEY_SEARCH_PREVIOUS       CTRL GDK_G
+// #define HOTKEY_SEARCH_NEXT           CTRL GDK_g
 #define    HOTKEY_TAB_ADD               CTRL GDK_T
 #define    HOTKEY_TAB_REMOVE            CTRL GDK_W
 #define    HOTKEY_TAB_PREVIOUS          CTRL GDK_Page_Up
@@ -146,18 +159,19 @@
 // #define HOTKEY_TOGGLE_BACKGROUND     CTRL GDK_KP_Delete
 // #define TOGGLE_BG_ORDER    "Image", "Transparent", "No background", "Opacity"
 
-// #define LABEL_DEFAULT_ENCODING       "Default Encoding"
-// #define LABEL_DIALOG_BACKGROUND_TINT "Background tint color"
+// #define LABEL_DEFAULT_ENCODING       "_Default Encoding"
+// #define LABEL_DIALOG_BACKGROUND_TINT "_Background tint color"
 // #define LABEL_DIALOG_CLOSE           "Do you really want to close it?"
-// #define LABEL_MENU_SATURATION        "Adjust saturation"
-// #define LABEL_MENU_TOGGLE_ANTI_ALIAS "Toggle anti-alias"
-// #define LABEL_MENU_TOGGLE_BG         "Toggle background"
-// #define LABEL_MENU_TOGGLE_DECORATED  "Toggle window decorated"
-// #define LABEL_MENU_TOGGLE_FULLSCREEN "Toggle fullscreen"
-// #define LABEL_MENU_TOGGLE_HOTKEYS    "Toggle hotkeys locking"
-// #define LABEL_MENU_TOGGLE_ON_TOP     "Toggle always on top"
-// #define LABEL_MENU_TOGGLE_SCROLLBAR  "Toggle scrollbar"
-// #define LABEL_MENU_TOGGLE_STATUS_BAR "Toggle status bar"
-// #define LABEL_MENU_TOGGLE_TABBAR     "Toggle tabbar"
-// #define LABEL_SUBMENU_ENCODING       "Character Encoding"
-// #define LABEL_SUBMENU_IME            "Input Methods"
+// #define LABEL_DIALOG_SEARCH          "Find"
+// #define LABEL_MENU_SATURATION        "_Adjust saturation"
+// #define LABEL_MENU_TOGGLE_ANTI_ALIAS "_Toggle anti-alias"
+// #define LABEL_MENU_TOGGLE_BG         "_Toggle background"
+// #define LABEL_MENU_TOGGLE_DECORATED  "_Toggle window decorated"
+// #define LABEL_MENU_TOGGLE_FULLSCREEN "_Toggle fullscreen"
+// #define LABEL_MENU_TOGGLE_HOTKEYS    "_Toggle hotkeys locking"
+// #define LABEL_MENU_TOGGLE_ON_TOP     "_Toggle always on top"
+// #define LABEL_MENU_TOGGLE_SCROLLBAR  "_Toggle scrollbar"
+// #define LABEL_MENU_TOGGLE_STATUS_BAR "_Toggle status bar"
+// #define LABEL_MENU_TOGGLE_TABBAR     "_Toggle tabbar"
+// #define LABEL_SUBMENU_ENCODING       "_Character Encoding"
+// #define LABEL_SUBMENU_IME            "_Input Methods"
